@@ -1,255 +1,256 @@
 try:
-    from .blockwise import blockwise, atop
+    from ..base import compute
+    from . import backends, fft, lib, linalg, ma, overlap, random
+    from .blockwise import atop, blockwise
+    from .chunk_types import register_chunk_type
     from .core import (
         Array,
-        block,
-        concatenate,
-        stack,
-        from_array,
-        store,
-        map_blocks,
-        to_hdf5,
-        to_npy_stack,
-        from_npy_stack,
-        from_delayed,
-        asarray,
-        asanyarray,
         PerformanceWarning,
+        asanyarray,
+        asarray,
+        block,
         broadcast_arrays,
         broadcast_to,
+        concatenate,
+        from_array,
+        from_delayed,
+        from_npy_stack,
         from_zarr,
+        map_blocks,
+        stack,
+        store,
+        to_hdf5,
+        to_npy_stack,
         to_zarr,
         unify_chunks,
     )
-    from .tiledb_io import from_tiledb, to_tiledb
-    from .numpy_compat import rollaxis, moveaxis
-    from .chunk_types import register_chunk_type
+    from .creation import (
+        arange,
+        diag,
+        diagonal,
+        empty_like,
+        eye,
+        fromfunction,
+        full_like,
+        indices,
+        linspace,
+        meshgrid,
+        ones_like,
+        pad,
+        repeat,
+        tile,
+        tri,
+        zeros_like,
+    )
+    from .gufunc import apply_gufunc, as_gufunc, gufunc
+    from .numpy_compat import moveaxis, rollaxis
+    from .optimization import optimize
+    from .overlap import map_overlap
+    from .percentile import percentile
+    from .rechunk import rechunk
+    from .reductions import (
+        all,
+        any,
+        argmax,
+        argmin,
+        argtopk,
+        cumprod,
+        cumsum,
+        max,
+        mean,
+        median,
+        min,
+        moment,
+        nanargmax,
+        nanargmin,
+        nancumprod,
+        nancumsum,
+        nanmax,
+        nanmean,
+        nanmedian,
+        nanmin,
+        nanprod,
+        nanstd,
+        nansum,
+        nanvar,
+        prod,
+        reduction,
+        std,
+        sum,
+        topk,
+        trace,
+        var,
+    )
+    from .reshape import reshape
     from .routines import (
-        take,
-        choose,
-        argwhere,
-        where,
-        coarsen,
-        insert,
-        delete,
-        append,
-        shape,
-        union1d,
-        ravel,
-        roll,
-        unique,
-        squeeze,
-        ptp,
-        diff,
-        ediff1d,
-        gradient,
-        bincount,
-        digitize,
-        histogram,
-        cov,
-        array,
-        dstack,
-        vstack,
-        hstack,
-        compress,
-        extract,
-        round,
-        count_nonzero,
-        flatnonzero,
-        nonzero,
-        unravel_index,
-        ravel_multi_index,
-        around,
-        isin,
-        isnull,
-        notnull,
-        isclose,
         allclose,
-        corrcoef,
-        swapaxes,
-        tensordot,
-        transpose,
-        dot,
-        vdot,
-        matmul,
-        outer,
+        append,
         apply_along_axis,
         apply_over_axes,
-        result_type,
+        argwhere,
+        around,
+        array,
         atleast_1d,
         atleast_2d,
         atleast_3d,
-        piecewise,
-        flip,
-        flipud,
-        fliplr,
-        einsum,
         average,
-        triu,
+        bincount,
+        choose,
+        coarsen,
+        compress,
+        corrcoef,
+        count_nonzero,
+        cov,
+        delete,
+        diff,
+        digitize,
+        dot,
+        dstack,
+        ediff1d,
+        einsum,
+        extract,
+        flatnonzero,
+        flip,
+        fliplr,
+        flipud,
+        gradient,
+        histogram,
+        histogramdd,
+        hstack,
+        insert,
+        isclose,
+        isin,
+        isnull,
+        matmul,
+        nonzero,
+        notnull,
+        outer,
+        piecewise,
+        ptp,
+        ravel,
+        ravel_multi_index,
+        result_type,
+        roll,
+        rot90,
+        round,
+        shape,
+        squeeze,
+        swapaxes,
+        take,
+        tensordot,
+        transpose,
         tril,
         tril_indices,
         tril_indices_from,
+        triu,
         triu_indices,
         triu_indices_from,
-        rot90,
+        union1d,
+        unique,
+        unravel_index,
+        vdot,
+        vstack,
+        where,
     )
-    from .reshape import reshape
+    from .tiledb_io import from_tiledb, to_tiledb
     from .ufunc import (
+        absolute,
         add,
-        subtract,
-        multiply,
-        divide,
-        logaddexp,
-        logaddexp2,
-        true_divide,
-        floor_divide,
-        negative,
-        power,
-        remainder,
-        mod,
-        conj,
-        exp,
-        exp2,
-        log,
-        log2,
-        log10,
-        log1p,
-        expm1,
-        sqrt,
-        square,
-        cbrt,
-        reciprocal,
-        sin,
-        cos,
-        tan,
-        arcsin,
+        angle,
         arccos,
+        arccosh,
+        arcsin,
+        arcsinh,
         arctan,
         arctan2,
-        hypot,
-        sinh,
-        cosh,
-        tanh,
-        arcsinh,
-        arccosh,
         arctanh,
-        deg2rad,
-        rad2deg,
-        greater,
-        greater_equal,
-        less,
-        less_equal,
-        not_equal,
-        equal,
-        maximum,
         bitwise_and,
+        bitwise_not,
         bitwise_or,
         bitwise_xor,
-        bitwise_not,
-        invert,
-        minimum,
-        logical_and,
-        logical_or,
-        logical_xor,
-        logical_not,
+        cbrt,
+        ceil,
+        clip,
+        conj,
+        copysign,
+        cos,
+        cosh,
+        deg2rad,
+        degrees,
+        divide,
+        divmod,
+        equal,
+        exp,
+        exp2,
+        expm1,
+        fabs,
+        fix,
+        float_power,
+        floor,
+        floor_divide,
         fmax,
         fmin,
-        isreal,
+        fmod,
+        frexp,
+        frompyfunc,
+        greater,
+        greater_equal,
+        hypot,
+        i0,
+        imag,
+        invert,
         iscomplex,
         isfinite,
         isinf,
+        isnan,
         isneginf,
         isposinf,
-        isnan,
-        signbit,
-        copysign,
-        nextafter,
-        spacing,
+        isreal,
         ldexp,
-        fmod,
-        floor,
-        ceil,
-        trunc,
-        degrees,
-        radians,
-        rint,
-        fix,
-        angle,
-        real,
-        imag,
-        clip,
-        fabs,
-        sign,
-        absolute,
-        i0,
-        sinc,
-        nan_to_num,
-        frexp,
+        less,
+        less_equal,
+        log,
+        log1p,
+        log2,
+        log10,
+        logaddexp,
+        logaddexp2,
+        logical_and,
+        logical_not,
+        logical_or,
+        logical_xor,
+        maximum,
+        minimum,
+        mod,
         modf,
-        divide,
-        frompyfunc,
-        float_power,
-        divmod,
+        multiply,
+        nan_to_num,
+        negative,
+        nextafter,
+        not_equal,
+        power,
+        rad2deg,
+        radians,
+        real,
+        reciprocal,
+        remainder,
+        rint,
+        sign,
+        signbit,
+        sin,
+        sinc,
+        sinh,
+        spacing,
+        sqrt,
+        square,
+        subtract,
+        tan,
+        tanh,
+        true_divide,
+        trunc,
     )
-    from .reductions import (
-        sum,
-        prod,
-        mean,
-        std,
-        var,
-        any,
-        all,
-        min,
-        max,
-        median,
-        moment,
-        trace,
-        argmin,
-        argmax,
-        nansum,
-        nanmean,
-        nanmedian,
-        nanstd,
-        nanvar,
-        nanmin,
-        nanmax,
-        nanargmin,
-        nanargmax,
-        cumsum,
-        cumprod,
-        topk,
-        argtopk,
-        nanprod,
-        nancumprod,
-        nancumsum,
-        reduction,
-    )
-    from .percentile import percentile
-    from . import lib
-    from . import ma
-    from . import random, linalg, overlap, fft, backends
-    from .overlap import map_overlap
-    from .wrap import ones, zeros, empty, full
-    from .creation import ones_like, zeros_like, empty_like, full_like
-    from .rechunk import rechunk
-    from ..base import compute
-    from .optimization import optimize
-    from .creation import (
-        arange,
-        linspace,
-        meshgrid,
-        indices,
-        diag,
-        eye,
-        tri,
-        fromfunction,
-        tile,
-        repeat,
-        pad,
-        diagonal,
-    )
-    from .gufunc import apply_gufunc, gufunc, as_gufunc
     from .utils import assert_eq
+    from .wrap import empty, full, ones, zeros
 
 except ImportError as e:
     msg = (
