@@ -1,4 +1,4 @@
-from .core import tensordot_lookup, concatenate_lookup, einsum_lookup
+from .core import concatenate_lookup, einsum_lookup, tensordot_lookup
 
 
 @tensordot_lookup.register_lazy("cupy")
@@ -17,18 +17,18 @@ def register_cupy():
         return cupy.einsum(*args, **kwargs)
 
 
+@tensordot_lookup.register_lazy("cupyx")
 @concatenate_lookup.register_lazy("cupyx")
 def register_cupyx():
 
     from cupyx.scipy.sparse import spmatrix
 
     try:
-        from cupy.sparse import hstack
-        from cupy.sparse import vstack
-    except ImportError:
+        from cupyx.scipy.sparse import hstack, vstack
+    except ImportError as e:
         raise ImportError(
             "Stacking of sparse arrays requires at least CuPy version 8.0.0"
-        )
+        ) from e
 
     def _concat_cupy_sparse(L, axis=0):
         if axis == 0:
@@ -43,6 +43,7 @@ def register_cupyx():
             raise ValueError(msg)
 
     concatenate_lookup.register(spmatrix, _concat_cupy_sparse)
+    tensordot_lookup.register(spmatrix, _tensordot_scipy_sparse)
 
 
 @tensordot_lookup.register_lazy("sparse")
@@ -54,6 +55,7 @@ def register_sparse():
     tensordot_lookup.register(sparse.COO, sparse.tensordot)
 
 
+@tensordot_lookup.register_lazy("scipy")
 @concatenate_lookup.register_lazy("scipy")
 def register_scipy_sparse():
     import scipy.sparse
@@ -71,3 +73,21 @@ def register_scipy_sparse():
             raise ValueError(msg)
 
     concatenate_lookup.register(scipy.sparse.spmatrix, _concatenate)
+    tensordot_lookup.register(scipy.sparse.spmatrix, _tensordot_scipy_sparse)
+
+
+def _tensordot_scipy_sparse(a, b, axes):
+    assert a.ndim == b.ndim == 2
+    assert len(axes[0]) == len(axes[1]) == 1
+    (a_axis,) = axes[0]
+    (b_axis,) = axes[1]
+    assert a_axis in (0, 1) and b_axis in (0, 1)
+    assert a.shape[a_axis] == b.shape[b_axis]
+    if a_axis == 0 and b_axis == 0:
+        return a.T * b
+    elif a_axis == 0 and b_axis == 1:
+        return a.T * b.T
+    elif a_axis == 1 and b_axis == 0:
+        return a * b
+    elif a_axis == 1 and b_axis == 1:
+        return a * b.T
