@@ -162,9 +162,9 @@ def transpose(a, axes=None):
     if axes:
         if len(axes) != a.ndim:
             raise ValueError("axes don't match array")
+        axes = tuple(d + a.ndim if d < 0 else d for d in axes)
     else:
         axes = tuple(range(a.ndim))[::-1]
-    axes = tuple(d + a.ndim if d < 0 else d for d in axes)
     return blockwise(
         np.transpose, axes, a, tuple(range(a.ndim)), dtype=a.dtype, axes=axes
     )
@@ -425,27 +425,9 @@ def _inner_apply_along_axis(arr, func1d, func1d_axis, func1d_args, func1d_kwargs
 @derived_from(np)
 def apply_along_axis(func1d, axis, arr, *args, dtype=None, shape=None, **kwargs):
     """
-    Apply a function to 1-D slices along the given axis. This is
-    a blocked variant of :func:`numpy.apply_along_axis` implemented via
+    This is a blocked variant of :func:`numpy.apply_along_axis` implemented via
     :func:`dask.array.map_blocks`
 
-    Parameters
-    ----------
-    func1d : callable
-        Function to apply to 1-D slices of the array along the given axis
-    axis : int
-        Axis along which func1d will be applied
-    arr : dask array
-        Dask array to which ``func1d`` will be applied
-    args : any
-        Additional arguments to ``func1d``.
-    dtype : str or dtype, optional
-        The dtype of the output of ``func1d``.
-    shape : tuple, optional
-        The shape of the output of ``func1d``.
-    kwargs : any
-        Additional keyword arguments for ``func1d``.
-
     Notes
     -----
     If either of `dtype` or `shape` are not provided, Dask attempts to
@@ -749,8 +731,13 @@ def histogram(a, bins=None, range=None, normed=False, weights=None, density=None
 
     Parameters
     ----------
-    a : array_like
-        Input data. The histogram is computed over the flattened array.
+    a : dask.array.Array
+        Input data; the histogram is computed over the flattened
+        array. If the ``weights`` argument is used, the chunks of
+        ``a`` are accessed to check chunking compatibility between
+        ``a`` and ``weights``. If ``weights`` is ``None``, a
+        :py:class:`dask.dataframe.Series` object can be passed as
+        input data.
     bins : int or sequence of scalars, optional
         Either an iterable specifying the ``bins`` or the number of ``bins``
         and a ``range`` argument is required as computing ``min`` and ``max``
@@ -771,7 +758,7 @@ def histogram(a, bins=None, range=None, normed=False, weights=None, density=None
     normed : bool, optional
         This is equivalent to the ``density`` argument, but produces incorrect
         results for unequal bin widths. It should not be used.
-    weights : array_like, optional
+    weights : dask.array.Array, optional
         A dask.array.Array of weights, of the same block structure as ``a``.  Each value in
         ``a`` only contributes its associated weight towards the bin count
         (instead of 1). If ``density`` is True, the weights are
@@ -788,6 +775,7 @@ def histogram(a, bins=None, range=None, normed=False, weights=None, density=None
         If ``density`` is True, ``bins`` cannot be a single-number delayed
         value. It must be a concrete number, or a (possibly-delayed)
         array/sequence of the bin edges.
+
     Returns
     -------
     hist : dask Array
@@ -796,7 +784,6 @@ def histogram(a, bins=None, range=None, normed=False, weights=None, density=None
     bin_edges : dask Array of dtype float
         Return the bin edges ``(length(hist)+1)``.
 
-
     Examples
     --------
     Using number of bins and range:
@@ -1038,10 +1025,10 @@ def histogramdd(sample, bins, range=None, normed=None, weights=None, density=Non
         An alias for the density argument that behaves identically. To
         avoid confusion with the broken argument to `histogram`,
         `density` should be preferred.
-    weights : dask Array, optional
+    weights : dask.array.Array, optional
         An array of values weighing each sample in the input data. The
-        chunks of the the weights must be identical to the chunking
-        along the 0th axis of the data sample.
+        chunks of the weights must be identical to the chunking along
+        the 0th (row) axis of the data sample.
     density : bool, optional
         If ``False`` (default), the returned array represents the
         number of samples in each bin. If ``True``, the returned array
@@ -1216,7 +1203,7 @@ def histogramdd(sample, bins, range=None, normed=None, weights=None, density=Non
         width_divider = asarray(width_divider, chunks=n.chunks)
         return n / width_divider / n.sum(), edges
 
-    return n, edges
+    return n, [asarray(entry) for entry in edges]
 
 
 @derived_from(np)
