@@ -1,20 +1,20 @@
-from operator import getitem
 from functools import partial
+from operator import getitem
 
 import numpy as np
 
-from .core import Array, elemwise, blockwise, apply_infer_dtype, asarray
-from .utils import empty_like_safe, IS_NEP18_ACTIVE
-from ..base import is_dask_collection, normalize_function
 from .. import core
+from ..base import is_dask_collection, normalize_function
 from ..highlevelgraph import HighLevelGraph
 from ..utils import (
-    funcname,
     derived_from,
+    funcname,
     is_dataframe_like,
-    is_series_like,
     is_index_like,
+    is_series_like,
 )
+from .core import Array, apply_infer_dtype, asarray, blockwise, elemwise
+from .utils import IS_NEP18_ACTIVE, empty_like_safe
 
 
 def __array_wrap__(numpy_ufunc, x, *args, **kwargs):
@@ -44,7 +44,7 @@ def wrap_elemwise(numpy_ufunc, array_wrap=False, source=np):
     return derived_from(source)(wrapped)
 
 
-class da_frompyfunc(object):
+class da_frompyfunc:
     """A serializable `frompyfunc` object"""
 
     def __init__(self, func, nin, nout):
@@ -86,7 +86,7 @@ def frompyfunc(func, nin, nout):
     return ufunc(da_frompyfunc(func, nin, nout))
 
 
-class ufunc(object):
+class ufunc:
     _forward_attrs = {
         "nin",
         "nargs",
