@@ -342,6 +342,7 @@ class Blockwise(Layer):
     def __dask_distributed_pack__(
         self, all_hlg_keys, known_key_dependencies, client, client_keys
     ):
+        from distributed.protocol import to_serialize
         from distributed.protocol.serialize import import_allowed_module
         from distributed.utils import CancelledError
         from distributed.utils_comm import unpack_remotedata
@@ -363,7 +364,9 @@ class Blockwise(Layer):
         dsk = (SubgraphCallable(dsk, self.output, tuple(keys2)),)
         dsk, dsk_unpacked_futures = unpack_remotedata(dsk, byte_keys=True)
 
-        func = dumps_function(dsk[0])
+        # Dump the function if concatenate is False, because
+        # we will not need to construct a nested task
+        func = to_serialize(dsk[0]) if self.concatenate else dumps_function(dsk[0])
         func_future_args = dsk[1:]
 
         indices = list(toolz.concat(indices2))
@@ -615,19 +618,19 @@ def _get_coord_mapping(
 
     Parameters
     ----------
-    dims: dict
+    dims : dict
         Mapping between each index specified in `argpairs` and
         the number of output blocks for that index. Corresponds
         to the Blockwise `dims` attribute.
-    output: str
+    output : str
         Corresponds to the Blockwise `output` attribute.
-    out_indices: tuple
+    out_indices : tuple
         Corresponds to the Blockwise `output_indices` attribute.
-    numblocks: dict
+    numblocks : dict
         Corresponds to the Blockwise `numblocks` attribute.
-    argpairs: tuple
+    argpairs : tuple
         Corresponds to the Blockwise `indices` attribute.
-    concatenate: bool
+    concatenate : bool
         Corresponds to the Blockwise `concatenate` attribute.
     """
 
@@ -728,7 +731,6 @@ def make_blockwise_graph(
 
     Examples
     --------
-
     Simple embarrassing map operation
 
     >>> inc = lambda x: x + 1
@@ -804,7 +806,6 @@ def make_blockwise_graph(
     {('z', 0): (add, ('x', 0), 100),
      ('z', 1): (add, ('x', 1), 100)}
 
-
     See Also
     --------
     dask.array.blockwise
@@ -821,8 +822,8 @@ def make_blockwise_graph(
         key_deps = {}
 
     if deserializing:
-        from distributed.protocol.serialize import import_allowed_module
-        from distributed.worker import dumps_function, warn_dumps
+        from distributed.protocol.serialize import import_allowed_module, to_serialize
+        from distributed.worker import dumps_function
     else:
         from importlib import import_module as import_allowed_module
 
@@ -917,21 +918,30 @@ def make_blockwise_graph(
         if deserializing:
             deps.update(func_future_args)
             args += list(func_future_args)
+
+        if deserializing and not concatenate:
+            # Construct a function/args/kwargs dict if we
+            # do not have a nested task (i.e. concatenate=False).
+            # TODO: Avoid using the iterate_collection-version
+            # of to_serialize if we know that are no embeded
+            # Serialized/Serialize objects in args and/or kwargs.
             if kwargs:
-                val = {
+                dsk[out_key] = {
                     "function": dumps_function(apply),
-                    "args": warn_dumps(args),
-                    "kwargs": warn_dumps(kwargs2),
+                    "args": to_serialize(args),
+                    "kwargs": to_serialize(kwargs2),
                 }
             else:
-                val = {"function": func, "args": warn_dumps(args)}
+                dsk[out_key] = {"function": func, "args": to_serialize(args)}
         else:
             if kwargs:
                 val = (apply, func, args, kwargs2)
             else:
                 args.insert(0, func)
                 val = tuple(args)
-        dsk[out_key] = val
+            # May still need to serialize (if concatenate=True)
+            dsk[out_key] = to_serialize(val) if deserializing else val
+
         if return_key_deps:
             key_deps[out_key] = deps
 
@@ -949,15 +959,14 @@ def lol_product(head, values):
 
     Parameters
     ----------
-
     head : tuple
         Prefix prepended to all results.
     values : sequence
         Mix of singletons and lists. Each list is substituted with every
         possible value and introduces another level of list in the output.
+
     Examples
     --------
-
     >>> lol_product(('x',), (1, 2, 3))
     ('x', 1, 2, 3)
     >>> lol_product(('x',), (1, [2, 3], 4, [5, 6]))  # doctest: +NORMALIZE_WHITESPACE
@@ -977,7 +986,6 @@ def lol_tuples(head, ind, values, dummies):
 
     Parameters
     ----------
-
     head : tuple
         The known tuple so far
     ind : Iterable
@@ -989,7 +997,6 @@ def lol_tuples(head, ind, values, dummies):
 
     Examples
     --------
-
     >>> lol_tuples(('x',), 'ij', {'i': 1, 'j': 0}, {})
     ('x', 1, 0)
 
@@ -1023,8 +1030,8 @@ def optimize_blockwise(graph, keys=()):
 
     Parameters
     ----------
-    full_graph: HighLevelGraph
-    keys: Iterable
+    graph : HighLevelGraph
+    keys : Iterable
         The keys of all outputs of all collections.
         Used to make sure that we don't fuse a layer needed by an output
 
@@ -1277,7 +1284,6 @@ def rewrite_blockwise(inputs):
 
 def zero_broadcast_dimensions(lol, nblocks):
     """
-
     >>> lol = [('x', 1, 0), ('x', 1, 1), ('x', 1, 2)]
     >>> nblocks = (4, 1, 2)  # note singleton dimension in second place
     >>> lol = [[('x', 1, 0, 0), ('x', 1, 0, 1)],
@@ -1302,13 +1308,13 @@ def broadcast_dimensions(argpairs, numblocks, sentinels=(1, (1,)), consolidate=N
 
     Parameters
     ----------
-    argpairs: iterable
+    argpairs : iterable
         name, ijk index pairs
-    numblocks: dict
+    numblocks : dict
         maps {name: number of blocks}
-    sentinels: iterable (optional)
+    sentinels : iterable (optional)
         values for singleton dimensions
-    consolidate: func (optional)
+    consolidate : func (optional)
         use this to reduce each set of common blocks into a smaller set
 
     Examples
@@ -1389,9 +1395,9 @@ def fuse_roots(graph: HighLevelGraph, keys: list):
 
     Parameters
     ----------
-    graph: HighLevelGraph
+    graph : HighLevelGraph
         The full graph of the computation
-    keys: list
+    keys : list
         The output keys of the computation, to be passed on to fuse
 
     See Also
