@@ -1,27 +1,26 @@
+import os
 from math import ceil
 from operator import getitem
-import os
 from threading import Lock
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 from tlz import merge
 
-from ...base import tokenize
 from ... import array as da
+from ...base import tokenize
+from ...dataframe.core import new_dd_object
 from ...delayed import delayed
-
-from ..core import DataFrame, Series, Index, new_dd_object, has_parallel_type
-from ..shuffle import set_partition
-from ..utils import insert_meta_param_description, check_meta, make_meta
-
 from ...utils import M, ensure_dict
+from ..core import DataFrame, Index, Series, has_parallel_type, new_dd_object
+from ..shuffle import set_partition
+from ..utils import check_meta, insert_meta_param_description, is_series_like, make_meta
 
 lock = Lock()
 
 
-def _meta_from_array(x, columns=None, index=None):
-    """ Create empty pd.DataFrame or pd.Series which has correct dtype """
+def _meta_from_array(x, columns=None, index=None, meta=None):
+    """ Create empty DataFrame or Series which has correct dtype """
 
     if x.ndim > 2:
         raise ValueError(
@@ -34,6 +33,9 @@ def _meta_from_array(x, columns=None, index=None):
             raise ValueError("'index' must be an instance of dask.dataframe.Index")
         index = index._meta
 
+    if meta is None:
+        meta = pd.DataFrame()
+
     if getattr(x.dtype, "names", None) is not None:
         # record array has named columns
         if columns is None:
@@ -47,9 +49,11 @@ def _meta_from_array(x, columns=None, index=None):
         dtypes = [fields[n][0] if n in fields else "f8" for n in columns]
     elif x.ndim == 1:
         if np.isscalar(columns) or columns is None:
-            return pd.Series([], name=columns, dtype=x.dtype, index=index)
+            return meta._constructor_sliced(
+                [], name=columns, dtype=x.dtype, index=index
+            )
         elif len(columns) == 1:
-            return pd.DataFrame(
+            return meta._constructor(
                 np.array([], dtype=x.dtype), columns=columns, index=index
             )
         raise ValueError(
@@ -69,11 +73,11 @@ def _meta_from_array(x, columns=None, index=None):
         dtypes = [x.dtype] * len(columns)
 
     data = {c: np.array([], dtype=dt) for (c, dt) in zip(columns, dtypes)}
-    return pd.DataFrame(data, columns=columns, index=index)
+    return meta._constructor(data, columns=columns, index=index)
 
 
-def from_array(x, chunksize=50000, columns=None):
-    """ Read any slicable array into a Dask Dataframe
+def from_array(x, chunksize=50000, columns=None, meta=None):
+    """Read any sliceable array into a Dask Dataframe
 
     Uses getitem syntax to pull slices out of the array.  The array need not be
     a NumPy array but must support slicing syntax
@@ -88,11 +92,27 @@ def from_array(x, chunksize=50000, columns=None):
 
         x.dtype == [('name', 'O'), ('balance', 'i8')]
 
+    Parameters
+    ----------
+    x : array_like
+    chunksize : int, optional
+        The number of rows per partition to use.
+    columns : list or string, optional
+        list of column names if DataFrame, single string if Series
+    meta : object, optional
+        An optional `meta` parameter can be passed for dask
+        to specify the concrete dataframe type to use for partitions of
+        the Dask dataframe. By default, pandas DataFrame is used.
+
+    Returns
+    -------
+    dask.DataFrame or dask.Series
+        A dask DataFrame/Series
     """
     if isinstance(x, da.Array):
-        return from_dask_array(x, columns=columns)
+        return from_dask_array(x, columns=columns, meta=meta)
 
-    meta = _meta_from_array(x, columns)
+    meta = _meta_from_array(x, columns, meta=meta)
 
     divisions = tuple(range(0, len(x), chunksize))
     divisions = divisions + (len(x) - 1,)
@@ -102,10 +122,10 @@ def from_array(x, chunksize=50000, columns=None):
     dsk = {}
     for i in range(0, int(ceil(len(x) / chunksize))):
         data = (getitem, x, slice(i * chunksize, (i + 1) * chunksize))
-        if isinstance(meta, pd.Series):
-            dsk[name, i] = (pd.Series, data, None, meta.dtype, meta.name)
+        if is_series_like(meta):
+            dsk[name, i] = (type(meta), data, None, meta.dtype, meta.name)
         else:
-            dsk[name, i] = (pd.DataFrame, data, None, meta.columns)
+            dsk[name, i] = (type(meta), data, None, meta.columns)
     return new_dd_object(dsk, name, meta, divisions)
 
 
@@ -115,7 +135,11 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
 
     This splits an in-memory Pandas dataframe into several parts and constructs
     a dask.dataframe from those parts on which Dask.dataframe can operate in
-    parallel.
+    parallel.  By default, the input dataframe will be sorted by the index to
+    produce cleanly-divided partitions (with known divisions).  To preserve the
+    input ordering, make sure the input index is monotonically-increasing. The
+    ``sort=False`` option will also avoid reordering, but will not result in
+    known divisions.
 
     Note that, despite parallelism, Dask.dataframe may not always be faster
     than Pandas.  We recommend that you stay with Pandas for as long as
@@ -132,8 +156,9 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
     chunksize : int, optional
         The number of rows per index partition to use.
     sort: bool
-        Sort input first to obtain cleanly divided partitions or don't sort and
-        don't get cleanly divided partitions
+        Sort the input by index first to obtain cleanly divided partitions
+        (with known divisions).  If False, the input will not be sorted, and
+        all divisions will be set to None. Default is True.
     name: string, optional
         An optional keyname for the dataframe.  Defaults to hashing the input
 
@@ -144,6 +169,7 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
 
     Examples
     --------
+    >>> from dask.dataframe import from_pandas
     >>> df = pd.DataFrame(dict(a=list('aabbcc'), b=list(range(6))),
     ...                   index=pd.date_range(start='20100101', periods=6))
     >>> ddf = from_pandas(df, npartitions=3)
@@ -207,7 +233,7 @@ def from_pandas(data, npartitions=None, chunksize=None, sort=True, name=None):
 
 
 def from_bcolz(x, chunksize=None, categorize=True, index=None, lock=lock, **kwargs):
-    """ Read BColz CTable into a Dask Dataframe
+    """Read BColz CTable into a Dask Dataframe
 
     BColz is a fast on-disk compressed column store with careful attention
     given to compression.  https://bcolz.readthedocs.io/en/latest/
@@ -231,9 +257,10 @@ def from_bcolz(x, chunksize=None, categorize=True, index=None, lock=lock, **kwar
     if lock is True:
         lock = Lock()
 
-    import dask.array as da
     import bcolz
 
+    import dask.array as da
+
     if isinstance(x, str):
         x = bcolz.ctable(rootdir=x)
     bc_chunklen = max(x[name].chunklen for name in x.names)
@@ -297,7 +324,7 @@ def from_bcolz(x, chunksize=None, categorize=True, index=None, lock=lock, **kwar
 
 
 def dataframe_from_ctable(x, slc, columns=None, categories=None, lock=lock):
-    """ Get DataFrame from bcolz.ctable
+    """Get DataFrame from bcolz.ctable
 
     Parameters
     ----------
@@ -372,8 +399,8 @@ def dataframe_from_ctable(x, slc, columns=None, categories=None, lock=lock):
     return result
 
 
-def from_dask_array(x, columns=None, index=None):
-    """ Create a Dask DataFrame from a Dask Array.
+def from_dask_array(x, columns=None, index=None, meta=None):
+    """Create a Dask DataFrame from a Dask Array.
 
     Converts a 2d array into a DataFrame and a 1d array into a Series.
 
@@ -388,11 +415,15 @@ def from_dask_array(x, columns=None, index=None):
         The default output index depends on whether `x` has any unknown
         chunks. If there are any unknown chunks, the output has ``None``
         for all the divisions (one per chunk). If all the chunks are known,
-        a default index with known divsions is created.
+        a default index with known divisions is created.
 
         Specifying `index` can be useful if you're conforming a Dask Array
         to an existing dask Series or DataFrame, and you would like the
         indices to match.
+    meta : object, optional
+        An optional `meta` parameter can be passed for dask
+        to specify the concrete dataframe type to be returned.
+        By default, pandas DataFrame is used.
 
     Examples
     --------
@@ -413,7 +444,7 @@ def from_dask_array(x, columns=None, index=None):
     dask.dataframe._Frame.values: Reverse conversion
     dask.dataframe._Frame.to_records: Reverse conversion
     """
-    meta = _meta_from_array(x, columns, index)
+    meta = _meta_from_array(x, columns, index, meta=meta)
 
     if x.ndim == 2 and len(x.chunks[1]) > 1:
         x = x.rechunk({1: x.shape[1]})
@@ -450,17 +481,17 @@ def from_dask_array(x, columns=None, index=None):
     for i, (chunk, ind) in enumerate(zip(x.__dask_keys__(), index)):
         if x.ndim == 2:
             chunk = chunk[0]
-        if isinstance(meta, pd.Series):
-            dsk[name, i] = (pd.Series, chunk, ind, x.dtype, meta.name)
+        if is_series_like(meta):
+            dsk[name, i] = (type(meta), chunk, ind, x.dtype, meta.name)
         else:
-            dsk[name, i] = (pd.DataFrame, chunk, ind, meta.columns)
+            dsk[name, i] = (type(meta), chunk, ind, meta.columns)
 
     to_merge.extend([ensure_dict(x.dask), dsk])
     return new_dd_object(merge(*to_merge), name, meta, divisions)
 
 
 def _link(token, result):
-    """ A dummy function to link results together in a graph
+    """A dummy function to link results together in a graph
 
     We use this to enforce an artificial sequential ordering on tasks that
     don't explicitly pass around a shared resource
@@ -502,7 +533,7 @@ def to_bag(df, index=False):
 
 
 def to_records(df):
-    """ Create Dask Array from a Dask Dataframe
+    """Create Dask Array from a Dask Dataframe
 
     Warning: This creates a dask.array without precise shape information.
     Operations that depend on shape information, like slicing or reshaping,
@@ -525,7 +556,7 @@ def to_records(df):
 def from_delayed(
     dfs, meta=None, divisions=None, prefix="from-delayed", verify_meta=True
 ):
-    """ Create Dask DataFrame from many Dask Delayed objects
+    """Create Dask DataFrame from many Dask Delayed objects
 
     Parameters
     ----------
@@ -589,7 +620,7 @@ def from_delayed(
 
 
 def sorted_division_locations(seq, npartitions=None, chunksize=None):
-    """ Find division locations and values in sorted list
+    """Find division locations and values in sorted list
 
     Examples
     --------
