@@ -718,6 +718,7 @@ def test_reductions(split_every):
 
         assert_eq(dds.sum(split_every=split_every), pds.sum())
         assert_eq(dds.prod(split_every=split_every), pds.prod())
+        assert_eq(dds.product(split_every=split_every), pds.product())
         assert_eq(dds.min(split_every=split_every), pds.min())
         assert_eq(dds.max(split_every=split_every), pds.max())
         assert_eq(dds.count(split_every=split_every), pds.count())
@@ -759,6 +760,10 @@ def test_reductions(split_every):
         assert_eq(
             dds.prod(skipna=False, split_every=split_every), pds.prod(skipna=False)
         )
+        assert_eq(
+            dds.product(skipna=False, split_every=split_every),
+            pds.product(skipna=False),
+        )
         assert_eq(dds.min(skipna=False, split_every=split_every), pds.min(skipna=False))
         assert_eq(dds.max(skipna=False, split_every=split_every), pds.max(skipna=False))
         assert_eq(dds.std(skipna=False, split_every=split_every), pds.std(skipna=False))
@@ -828,7 +833,9 @@ def test_reductions_timedelta(split_every):
         (pd.Series([1, 2.5, 6]), None, None),
     ],
 )
-@pytest.mark.parametrize("redfunc", ["sum", "prod", "min", "max", "mean", "var", "std"])
+@pytest.mark.parametrize(
+    "redfunc", ["sum", "prod", "product", "min", "max", "mean", "var", "std"]
+)
 def test_reductions_out(frame, axis, out, redfunc):
     dsk_in = dd.from_pandas(frame, 3)
     dsk_out = dd.from_pandas(pd.Series([0]), 1).sum()
@@ -919,6 +926,10 @@ def test_deterministic_reduction_names(split_every):
             x.prod(split_every=split_every)._name
             == x.prod(split_every=split_every)._name
         )
+        assert (
+            x.product(split_every=split_every)._name
+            == x.product(split_every=split_every)._name
+        )
         assert (
             x.min(split_every=split_every)._name == x.min(split_every=split_every)._name
         )
@@ -963,6 +974,7 @@ def test_reduction_series_invalid_axis():
         for s in [ddf1.a, pdf1.a]:  # both must behave the same
             pytest.raises(ValueError, lambda: s.sum(axis=axis))
             pytest.raises(ValueError, lambda: s.prod(axis=axis))
+            pytest.raises(ValueError, lambda: s.product(axis=axis))
             pytest.raises(ValueError, lambda: s.min(axis=axis))
             pytest.raises(ValueError, lambda: s.max(axis=axis))
             # only count doesn't have axis keyword
@@ -984,6 +996,7 @@ def test_reductions_non_numeric_dtypes():
     dds = dd.from_pandas(pds, 2)
     assert_eq(dds.sum(), pds.sum())
     check_raises(dds, pds, "prod")
+    check_raises(dds, pds, "product")
     assert_eq(dds.min(), pds.min())
     assert_eq(dds.max(), pds.max())
     assert_eq(dds.count(), pds.count())
@@ -1003,6 +1016,7 @@ def test_reductions_non_numeric_dtypes():
 
         check_raises(dds, pds, "sum")
         check_raises(dds, pds, "prod")
+        check_raises(dds, pds, "product")
         assert_eq(dds.min(), pds.min())
         assert_eq(dds.max(), pds.max())
         assert_eq(dds.count(), pds.count())
@@ -1051,6 +1065,7 @@ def test_reductions_frame(split_every):
 
     assert_eq(ddf1.sum(split_every=split_every), pdf1.sum())
     assert_eq(ddf1.prod(split_every=split_every), pdf1.prod())
+    assert_eq(ddf1.product(split_every=split_every), pdf1.product())
     assert_eq(ddf1.min(split_every=split_every), pdf1.min())
     assert_eq(ddf1.max(split_every=split_every), pdf1.max())
     assert_eq(ddf1.count(split_every=split_every), pdf1.count())
@@ -1065,6 +1080,9 @@ def test_reductions_frame(split_every):
     for axis in [0, 1, "index", "columns"]:
         assert_eq(ddf1.sum(axis=axis, split_every=split_every), pdf1.sum(axis=axis))
         assert_eq(ddf1.prod(axis=axis, split_every=split_every), pdf1.prod(axis=axis))
+        assert_eq(
+            ddf1.product(axis=axis, split_every=split_every), pdf1.product(axis=axis)
+        )
         assert_eq(ddf1.min(axis=axis, split_every=split_every), pdf1.min(axis=axis))
         assert_eq(ddf1.max(axis=axis, split_every=split_every), pdf1.max(axis=axis))
         assert_eq(ddf1.count(axis=axis, split_every=split_every), pdf1.count(axis=axis))
@@ -1154,6 +1172,7 @@ def test_reductions_frame_dtypes():
         )
 
     assert_eq(df.prod(), ddf.prod())
+    assert_eq(df.product(), ddf.product())
     assert_eq(df.min(), ddf.min())
     assert_eq(df.max(), ddf.max())
     assert_eq(df.count(), ddf.count())
@@ -1215,6 +1234,7 @@ def test_reductions_frame_nan(split_every):
     ddf = dd.from_pandas(df, 3)
     assert_eq(df.sum(), ddf.sum(split_every=split_every))
     assert_eq(df.prod(), ddf.prod(split_every=split_every))
+    assert_eq(df.product(), ddf.product(split_every=split_every))
     assert_eq(df.min(), ddf.min(split_every=split_every))
     assert_eq(df.max(), ddf.max(split_every=split_every))
     assert_eq(df.count(), ddf.count(split_every=split_every))
@@ -1235,6 +1255,9 @@ def test_reductions_frame_nan(split_every):
         assert_eq(
             df.prod(skipna=False), ddf.prod(skipna=False, split_every=split_every)
         )
+        assert_eq(
+            df.product(skipna=False), ddf.product(skipna=False, split_every=split_every)
+        )
         assert_eq(df.min(skipna=False), ddf.min(skipna=False, split_every=split_every))
         assert_eq(df.max(skipna=False), ddf.max(skipna=False, split_every=split_every))
         assert_eq(df.std(skipna=False), ddf.std(skipna=False, split_every=split_every))
@@ -1264,6 +1287,10 @@ def test_reductions_frame_nan(split_every):
             df.prod(axis=1, skipna=False),
             ddf.prod(axis=1, skipna=False, split_every=split_every),
         )
+        assert_eq(
+            df.product(axis=1, skipna=False),
+            ddf.product(axis=1, skipna=False, split_every=split_every),
+        )
         assert_eq(
             df.min(axis=1, skipna=False),
             ddf.min(axis=1, skipna=False, split_every=split_every),
@@ -1370,7 +1397,7 @@ def test_empty_df_reductions(func):
     assert_eq(dsk_func(ddf), pd_func(pdf))
 
 
-@pytest.mark.parametrize("method", ["sum", "prod"])
+@pytest.mark.parametrize("method", ["sum", "prod", "product"])
 @pytest.mark.parametrize("min_count", [0, 9])
 def test_series_agg_with_min_count(method, min_count):
     df = pd.DataFrame([[1]], columns=["a"])
