@@ -1,15 +1,12 @@
-import pandas as pd
 import numpy as np
-
+import pandas as pd
 import pytest
 
 import dask
 import dask.dataframe as dd
-
-from dask.dataframe._compat import tm, PANDAS_GT_100
+from dask.dataframe._compat import PANDAS_GT_100, PANDAS_GT_110, PANDAS_GT_120, tm
 from dask.dataframe.indexing import _coerce_loc_index
-from dask.dataframe.utils import assert_eq, make_meta, PANDAS_VERSION
-
+from dask.dataframe.utils import assert_eq, make_meta
 
 dsk = {
     ("x", 0): pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}, index=[0, 1, 3]),
@@ -19,6 +16,9 @@ dsk = {
 meta = make_meta({"a": "i8", "b": "i8"}, index=pd.Index([], "i8"))
 d = dd.DataFrame(dsk, "x", meta, [0, 5, 9, 9])
 full = d.compute()
+CHECK_FREQ = {}
+if PANDAS_GT_110:
+    CHECK_FREQ["check_freq"] = False
 
 
 def test_loc():
@@ -369,24 +369,35 @@ def test_loc_timestamp_str():
     assert_eq(df.loc["2011-01-02"], ddf.loc["2011-01-02"])
     assert_eq(df.loc["2011-01-02":"2011-01-10"], ddf.loc["2011-01-02":"2011-01-10"])
     # same reso, dask result is always DataFrame
-    assert_eq(df.loc["2011-01-02 10:00"].to_frame().T, ddf.loc["2011-01-02 10:00"])
+    assert_eq(
+        df.loc["2011-01-02 10:00"].to_frame().T,
+        ddf.loc["2011-01-02 10:00"],
+        **CHECK_FREQ
+    )
 
     # series
-    assert_eq(df.A.loc["2011-01-02"], ddf.A.loc["2011-01-02"])
-    assert_eq(df.A.loc["2011-01-02":"2011-01-10"], ddf.A.loc["2011-01-02":"2011-01-10"])
+    assert_eq(df.A.loc["2011-01-02"], ddf.A.loc["2011-01-02"], **CHECK_FREQ)
+    assert_eq(
+        df.A.loc["2011-01-02":"2011-01-10"],
+        ddf.A.loc["2011-01-02":"2011-01-10"],
+        **CHECK_FREQ
+    )
 
     # slice with timestamp (dask result must be DataFrame)
     assert_eq(
         df.loc[pd.Timestamp("2011-01-02")].to_frame().T,
         ddf.loc[pd.Timestamp("2011-01-02")],
+        **CHECK_FREQ
     )
     assert_eq(
         df.loc[pd.Timestamp("2011-01-02") : pd.Timestamp("2011-01-10")],
         ddf.loc[pd.Timestamp("2011-01-02") : pd.Timestamp("2011-01-10")],
+        **CHECK_FREQ
     )
     assert_eq(
         df.loc[pd.Timestamp("2011-01-02 10:00")].to_frame().T,
         ddf.loc[pd.Timestamp("2011-01-02 10:00")],
+        **CHECK_FREQ
     )
 
     df = pd.DataFrame(
@@ -417,25 +428,51 @@ def test_getitem_timestamp_str():
     ddf = dd.from_pandas(df, 10)
 
     # partial string slice
-    assert_eq(df["2011-01-02"], ddf["2011-01-02"])
-    assert_eq(df["2011-01-02":"2011-01-10"], df["2011-01-02":"2011-01-10"])
+    # TODO(pandas) starting with pandas 1.2, __getitem__ with an implicit slice
+    # is deprecated -> should we deprecate this in dask as well?
+    assert_eq(df.loc["2011-01-02"], ddf["2011-01-02"])
+    assert_eq(df["2011-01-02":"2011-01-10"], ddf["2011-01-02":"2011-01-10"])
 
     df = pd.DataFrame(
         {"A": np.random.randn(100), "B": np.random.randn(100)},
         index=pd.date_range("2011-01-01", freq="D", periods=100),
     )
     ddf = dd.from_pandas(df, 50)
-    assert_eq(df["2011-01"], ddf["2011-01"])
-    assert_eq(df["2011"], ddf["2011"])
+    assert_eq(df.loc["2011-01"], ddf["2011-01"])
+    assert_eq(df.loc["2011"], ddf["2011"])
 
     assert_eq(df["2011-01":"2012-05"], ddf["2011-01":"2012-05"])
     assert_eq(df["2011":"2015"], ddf["2011":"2015"])
 
 
+@pytest.mark.xfail(
+    not PANDAS_GT_110, reason=".loc partial index with PeriodIndex not yet supported"
+)
 def test_loc_period_str():
     # .loc with PeriodIndex doesn't support partial string indexing
     # https://github.com/pydata/pandas/issues/13429
-    pass
+    # -> this started working in pandas 1.1
+    df = pd.DataFrame(
+        {"A": np.random.randn(100), "B": np.random.randn(100)},
+        index=pd.period_range("2011-01-01", freq="H", periods=100),
+    )
+    ddf = dd.from_pandas(df, 10)
+
+    # partial string slice
+    assert_eq(df.loc["2011-01-02"], ddf.loc["2011-01-02"])
+    assert_eq(df.loc["2011-01-02":"2011-01-10"], ddf.loc["2011-01-02":"2011-01-10"])
+    # same reso, dask result is always DataFrame
+
+    df = pd.DataFrame(
+        {"A": np.random.randn(100), "B": np.random.randn(100)},
+        index=pd.period_range("2011-01-01", freq="D", periods=100),
+    )
+    ddf = dd.from_pandas(df, 50)
+    assert_eq(df.loc["2011-01"], ddf.loc["2011-01"])
+    assert_eq(df.loc["2011"], ddf.loc["2011"])
+
+    assert_eq(df.loc["2011-01":"2012-05"], ddf.loc["2011-01":"2012-05"])
+    assert_eq(df.loc["2011":"2015"], ddf.loc["2011":"2015"])
 
 
 def test_getitem_period_str():
@@ -447,8 +484,11 @@ def test_getitem_period_str():
     ddf = dd.from_pandas(df, 10)
 
     # partial string slice
-    assert_eq(df["2011-01-02"], ddf["2011-01-02"])
-    assert_eq(df["2011-01-02":"2011-01-10"], df["2011-01-02":"2011-01-10"])
+    # TODO(pandas) starting with pandas 1.2, __getitem__ with an implicit slice
+    # is deprecated -> should we deprecate this in dask as well?
+    if not PANDAS_GT_120:
+        assert_eq(df["2011-01-02"], ddf["2011-01-02"])
+    assert_eq(df["2011-01-02":"2011-01-10"], ddf["2011-01-02":"2011-01-10"])
     # same reso, dask result is always DataFrame
 
     df = pd.DataFrame(
@@ -456,8 +496,9 @@ def test_getitem_period_str():
         index=pd.period_range("2011-01-01", freq="D", periods=100),
     )
     ddf = dd.from_pandas(df, 50)
-    assert_eq(df["2011-01"], ddf["2011-01"])
-    assert_eq(df["2011"], ddf["2011"])
+    if not PANDAS_GT_120:
+        assert_eq(df["2011-01"], ddf["2011-01"])
+        assert_eq(df["2011"], ddf["2011"])
 
     assert_eq(df["2011-01":"2012-05"], ddf["2011-01":"2012-05"])
     assert_eq(df["2011":"2015"], ddf["2011":"2015"])
@@ -499,7 +540,6 @@ def test_to_frame():
     assert_eq(df.index.to_frame(), ddf.index.to_frame())
 
 
-@pytest.mark.skipif(PANDAS_VERSION < "0.24.0", reason="No renaming for index")
 def test_to_frame_name():
     # Test for time index
     df = pd.DataFrame(
