@@ -77,12 +77,13 @@ Work towards *small goals* with *big steps*.
 """
 from collections import defaultdict
 from math import log
-from .core import get_dependencies, reverse_dict, get_deps, getcycle  # noqa: F401
+
+from .core import get_dependencies, get_deps, getcycle, reverse_dict  # noqa: F401
 from .utils_test import add, inc  # noqa: F401
 
 
 def order(dsk, dependencies=None):
-    """ Order nodes in dask graph
+    """Order nodes in dask graph
 
     This produces an ordering over our tasks that we use to break ties when
     executing.  We do this ahead of time to reduce a bit of stress on the
@@ -113,6 +114,7 @@ def order(dsk, dependencies=None):
     dependents = reverse_dict(dependencies)
     num_needed, total_dependencies = ndependencies(dependencies, dependents)
     metrics = graph_metrics(dependencies, dependents, total_dependencies)
+
     if len(metrics) != len(dsk):
         cycle = getcycle(dsk, None)
         raise RuntimeError(
@@ -120,6 +122,16 @@ def order(dsk, dependencies=None):
             % "\n  -> ".join(str(x) for x in cycle)
         )
 
+    # Single root nodes that depend on everything. These cause issues for
+    # the current ordering algorithm, since we often hit the root node
+    # and fell back to the key tie-breaker to choose which immediate dependency
+    # to finish next, rather than finishing off subtrees.
+    # So under the special case of a single root node that depends on the entire
+    # tree, we skip processing it normally.
+    # See https://github.com/dask/dask/issues/6745
+    root_nodes = {k for k, v in dependents.items() if not v}
+    skip_root_node = len(root_nodes) == 1 and len(dsk) > 1
+
     # Leaf nodes.  We choose one--the initial node--for each weakly connected subgraph.
     # Let's calculate the `initial_stack_key` as we determine `init_stack` set.
     init_stack = {
@@ -154,7 +166,7 @@ def order(dsk, dependencies=None):
     initial_stack_key = init_stack.__getitem__
 
     def dependents_key(x):
-        """ Choose a path from our starting task to our tactical goal
+        """Choose a path from our starting task to our tactical goal
 
         This path is connected to a large goal, but focuses on completing
         a small goal and being memory efficient.
@@ -168,7 +180,7 @@ def order(dsk, dependencies=None):
         )
 
     def dependencies_key(x):
-        """ Choose which dependency to run as part of a reverse DFS
+        """Choose which dependency to run as part of a reverse DFS
 
         This is very similar to both ``initial_stack_key``.
         """
@@ -279,7 +291,11 @@ def order(dsk, dependencies=None):
                 item = inner_stack_pop()
                 if item in result:
                     continue
+
                 if num_needed[item]:
+                    if skip_root_node and item in root_nodes:
+                        continue
+
                     inner_stack.append(item)
                     deps = set_difference(dependencies[item], result)
                     if 1 < len(deps) < 1000:
@@ -484,7 +500,9 @@ def order(dsk, dependencies=None):
             init_stack_pop = init_stack.pop
             is_init_sorted = True
 
-        item = init_stack_pop()
+        if skip_root_node and item in root_nodes:
+            item = init_stack_pop()
+
         while item in result:
             item = init_stack_pop()
         inner_stacks_append([item])
@@ -493,7 +511,7 @@ def order(dsk, dependencies=None):
 
 
 def graph_metrics(dependencies, dependents, total_dependencies):
-    r""" Useful measures of a graph used by ``dask.order.order``
+    r"""Useful measures of a graph used by ``dask.order.order``
 
     Example DAG (a1 has no dependencies; b2 and c1 are root nodes):
 
@@ -504,8 +522,10 @@ def graph_metrics(dependencies, dependents, total_dependencies):
       a1
 
     For each key we return:
-    1.  The number of keys that can only be run after this key is run.  The
-        root nodes have value 1 while deep child nodes will have larger values.
+
+    1.  **total_dependents**: The number of keys that can only be run
+        after this key is run.  The root nodes have value 1 while deep child
+        nodes will have larger values.
 
         1
         |
@@ -513,8 +533,8 @@ def graph_metrics(dependencies, dependents, total_dependencies):
          \ /
           4
 
-    2.  The minimum value of the total number of dependencies of
-        all final dependents (see module-level comment for more).
+    2.  **min_dependencies**: The minimum value of the total number of
+        dependencies of all final dependents (see module-level comment for more).
         In other words, the minimum of ``ndependencies`` of root
         nodes connected to the current node.
 
@@ -524,8 +544,8 @@ def graph_metrics(dependencies, dependents, total_dependencies):
          \ /
           2
 
-    3.  The maximum value of the total number of dependencies of
-        all final dependents (see module-level comment for more).
+    3.  **max_dependencies**: The maximum value of the total number of
+        dependencies of all final dependents (see module-level comment for more).
         In other words, the maximum of ``ndependencies`` of root
         nodes connected to the current node.
 
@@ -535,7 +555,7 @@ def graph_metrics(dependencies, dependents, total_dependencies):
          \ /
           3
 
-    4.  The minimum height from a root node
+    4.  **min_height**: The minimum height from a root node
 
         0
         |
@@ -543,7 +563,7 @@ def graph_metrics(dependencies, dependents, total_dependencies):
          \ /
           1
 
-    5.  The maximum height from a root node
+    5.  **max_height**: The maximum height from a root node
 
         0
         |
@@ -620,7 +640,7 @@ def graph_metrics(dependencies, dependents, total_dependencies):
 
 
 def ndependencies(dependencies, dependents):
-    """ Number of total data elements on which this key depends
+    """Number of total data elements on which this key depends
 
     For each key we return the number of tasks that must be run for us to run
     this task.
@@ -665,8 +685,8 @@ def ndependencies(dependencies, dependents):
     return num_dependencies, result
 
 
-class StrComparable(object):
-    """ Wrap object so that it defaults to string comparison
+class StrComparable:
+    """Wrap object so that it defaults to string comparison
 
     When comparing two objects of different types Python fails
 
